@@ -11,7 +11,9 @@ class Disbursement:
         self.disbursements_apiuser = os.environ('DISBURSEMENT_USER_ID')
         self.api_key_disbursements = os.environ('DISBURSEMENT_API_SECRET')
         self.environment_mode = os.environ.get('MTN_ENVIRONMENT')
+        self.callback_url = os.environ.get('CALLBACK_URL')
         self.base_url = os.environ.get('BASE_URL')
+        
 
         if self.environment_mode == "sandbox":
             self.base_url = "https://sandbox.momodeveloper.mtn.com"
@@ -79,6 +81,7 @@ class Disbursement:
         headers = {
             'X-Reference-Id': str(uuid4()),
             'X-Target-Environment': self.environment_mode,
+            'X-Callback-Url': self.callback_url,
             'Ocp-Apim-Subscription-Key': self.subscription_key,
             'Content-Type': 'application/json',
             'Authorization':  "Bearer " + str(self.authToken()["access_token"])
